==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GotFocusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GotFocusEventArgsDescription } from "./GotFocusEventArgsDescription";
/**
 * @hidden
 */
export let GotFocusEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GotFocusEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GotFocusEventArgsDescriptionMetadata.a == null) {
                GotFocusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GotFocusEventArgsDescriptionMetadata.c(GotFocusEventArgsDescriptionMetadata.a);
            }
            if (a.k(GotFocusEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GotFocusEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            GotFocusEventArgsDescriptionMetadata.b(a);
            a.ad("GotFocusEventArgs", () => new GotFocusEventArgsDescription());
            a.ac("GotFocusEventArgs", GotFocusEventArgsDescriptionMetadata.a);
        }
    }
    GotFocusEventArgsDescriptionMetadata.$t = markType(GotFocusEventArgsDescriptionMetadata, 'GotFocusEventArgsDescriptionMetadata');
    GotFocusEventArgsDescriptionMetadata.a = null;
    return GotFocusEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GotFocusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GotFocusEventArgsDescription } from "./GotFocusEventArgsDescription";
/**
 * @hidden
 */
export let GotFocusEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GotFocusEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GotFocusEventArgsDescriptionMetadata.a == null) {
                GotFocusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GotFocusEventArgsDescriptionMetadata.c(GotFocusEventArgsDescriptionMetadata.a);
            }
            if (a.k(GotFocusEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GotFocusEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            GotFocusEventArgsDescriptionMetadata.b(a);
            a.ae("GotFocusEventArgs", () => new GotFocusEventArgsDescription());
            a.ad("GotFocusEventArgs", GotFocusEventArgsDescriptionMetadata.a);
        }
    }
    GotFocusEventArgsDescriptionMetadata.$t = markType(GotFocusEventArgsDescriptionMetadata, 'GotFocusEventArgsDescriptionMetadata');
    GotFocusEventArgsDescriptionMetadata.a = null;
    return GotFocusEventArgsDescriptionMetadata;
})();
